==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Il controllo è quasi completo, grazie per la pazienza.</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Preparazione in corso</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>Visualizza Log</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>Aggiornamento riuscito</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Il tuo computer si riavvierà a breve %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Il tuo computer si spegnerà a breve %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>Nascondi Log</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Aggiornamento fallito</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Errore sconosciuto</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Backup fallito</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Impossibile eseguire il backup del sistema. Se continui con gli aggiornamenti, non potrai ripristinare il vecchio sistema in un secondo momento.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Spazio sul disco insufficiente. Pulisci il disco e riprova.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Impossibile connettersi ai servizi di backup. Per favore controlla e riprova.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Impossibile connettersi ai servizi di aggiornamento. Per favore controlla e riprova.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Errore dipendenza</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Errore DPKG</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Nuovo backup</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Procedi all&apos;aggiornamento</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Vai al Desktop</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Preparazione per gli aggiornamenti...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Non forzare l&apos;arresto o lo spegnimento durante l&apos;installazione degli aggiornamenti. In caso contrario, il sistema potrebbe danneggiarsi.</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.31.tar.xz: BUILD/src/dde-update/translations/dde-update_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Il controllo è quasi completo, grazie per la pazienza.</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Preparazione in corso</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>Aggiornamento riuscito</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Il tuo computer si riavvierà a breve %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Il tuo computer si spegnerà a breve %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Aggiornamento fallito</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Errore sconosciuto</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Backup fallito</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Impossibile eseguire il backup del sistema. Se continui con gli aggiornamenti, non potrai ripristinare il vecchio sistema in un secondo momento.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Spazio sul disco insufficiente. Pulisci il disco e riprova.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Impossibile connettersi ai servizi di backup. Per favore controlla e riprova.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Impossibile connettersi ai servizi di aggiornamento. Per favore controlla e riprova.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Errore dipendenza</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Errore DPKG</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Nuovo backup</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Procedi all&apos;aggiornamento</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Vai al Desktop</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Preparazione per gli aggiornamenti...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Non forzare l&apos;arresto o lo spegnimento durante l&apos;installazione degli aggiornamenti. In caso contrario, il sistema potrebbe danneggiarsi.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
